pub enum ProofError {
Show 17 variants
WrongNumberOfInputs,
WrongNumberOfOutputs,
ChallengeInputMismatch,
NonSpendableInput(usize),
NotSignedInput(usize),
UnsupportedSighashType(usize),
NeitherWitnessNorLegacy(usize),
SignatureValidation(usize, String),
InvalidOutput,
InAndOutValueNotEqual,
OutpointNotFound(usize),
MissingConfirmationInfo,
ForeignUtxo(AddForeignUtxoError),
TxError(CreateTxError),
TxExtraction(Box<ExtractTxError>),
Wallet(Error),
Sign(SignerError),
}Expand description
Proof error
Variants
WrongNumberOfInputs
Less than two inputs
WrongNumberOfOutputs
Must have exactly 1 output
ChallengeInputMismatch
Challenge input does not match
NonSpendableInput(usize)
Found an input other than the challenge which is not spendable. Holds the position of the input.
NotSignedInput(usize)
Found an input that has no signature at position
UnsupportedSighashType(usize)
Found an input with an unsupported SIGHASH type at position
NeitherWitnessNorLegacy(usize)
Found an input that is neither witness nor legacy at position
SignatureValidation(usize, String)
Signature validation failed
InvalidOutput
The output is not valid
InAndOutValueNotEqual
Input and output values are not equal, implying a miner fee
OutpointNotFound(usize)
No matching outpoint found
MissingConfirmationInfo
Failed to retrieve the block height of a Tx or UTXO
ForeignUtxo(AddForeignUtxoError)
Error adding foreign UTXO
TxError(CreateTxError)
Failed to create a transaction
TxExtraction(Box<ExtractTxError>)
Failed to extract TX from a PSBT
Wallet(Error)
Failed to construct a Wallet
Sign(SignerError)
Failed to sign a transaction